/*
 * Copyright (c) 2018 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0

Item {
    
    property string azimuth: '0'
    property string elevation: '1'
    property string width45: '2'
    
    property double azimuthDefault: 0.375
    property double elevationDefault: 0.333
	property double width45Default: 0.25
	
	property real maxFilterPercent: 100.00
    property real maxUserPercent: 100.00
    property real defaultValue: 2.5 / maxFilterPercent
    
    property var defaultParameters: [azimuth, elevation, width45]
    
    width: 350
    height: 450
    
    Component.onCompleted: {
        if (filter.isNew) {
            filter.set(azimuth, azimuthDefault)
            filter.set(elevation, elevationDefault)
            filter.set(width45, width45Default)
            
            filter.savePreset(preset.defaultParameters)
        }
        azimuthSlider.value = filter.getDouble(azimuth) * maxFilterPercent
        elevationSlider.value = filter.getDouble(elevation) * maxFilterPercent
        width45Slider.value = filter.getDouble(width45) * maxFilterPercent
    }

    function setControls() {
        azimuthSlider.value = filter.getDouble(azimuth) * maxFilterPercent
        elevationSlider.value = filter.getDouble(elevation) * maxFilterPercent
        width45Slider.value = filter.getDouble(width45) * maxFilterPercent
    }

    GridLayout {
        anchors.fill: parent
        anchors.margins: 8
        columns: 3

        Label {
            text: qsTr('Preset')
            Layout.alignment: Qt.AlignRight
        }
        Preset {
            id: preset
            parameters: [azimuth, elevation, width45]
            Layout.columnSpan: 3
            onPresetSelected: setControls()
        }

        Label {
            text: qsTr('Light Direction')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: azimuthSlider
            minimumValue: 0.00
            maximumValue: maxUserPercent
			stepSize: 0.01
            decimals: 2
			suffix: ' %'
            //value: filter.getDouble(azimuth)
            onValueChanged: filter.set(azimuth, value / maxFilterPercent)
        }
        UndoButton {
            onClicked: azimuthSlider.value = azimuthDefault * maxFilterPercent
        }
        
        Label {
            text: qsTr('Background Lightness')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: elevationSlider
            minimumValue: 0.00
            maximumValue: maxUserPercent
			stepSize: 0.01
            decimals: 2
			suffix: ' %'
            //value: filter.getDouble(azimuth)
            onValueChanged: filter.set(elevation, value / maxFilterPercent)
        }
        UndoButton {
            onClicked: elevationSlider.value = elevationDefault * maxFilterPercent
        }


        Label {
            text: qsTr('Bump Height')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: width45Slider
            minimumValue: 0.00
            maximumValue: maxUserPercent
			stepSize: 0.01
            decimals: 2
			suffix: ' %'
            //value: filter.getDouble(width45)
            onValueChanged: filter.set(width45, value / maxFilterPercent)
            }
        UndoButton {
            onClicked: width45Slider.value = width45Default * maxFilterPercent
        }

        Item {
            Layout.fillHeight: true;
        }
    }
    // Connections {
       // target: producer
      //  onPositionChanged: setControls()
    // }
  }